Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(106)

Unified Diff: third_party/WebKit/Source/bindings/core/v8/ScriptCustomElementDefinitionBuilder.cpp

Issue 2277713002: Rename CustomElementsRegistry to CustomElementRegistry (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/bindings/core/v8/ScriptCustomElementDefinitionBuilder.cpp
diff --git a/third_party/WebKit/Source/bindings/core/v8/ScriptCustomElementDefinitionBuilder.cpp b/third_party/WebKit/Source/bindings/core/v8/ScriptCustomElementDefinitionBuilder.cpp
index a26b1ac8e04cae60ac30a4177fc5a8fd456dc64f..6139058a7107d9839bb5736cf8e6be2003410fa5 100644
--- a/third_party/WebKit/Source/bindings/core/v8/ScriptCustomElementDefinitionBuilder.cpp
+++ b/third_party/WebKit/Source/bindings/core/v8/ScriptCustomElementDefinitionBuilder.cpp
@@ -20,7 +20,7 @@ ScriptCustomElementDefinitionBuilder* ScriptCustomElementDefinitionBuilder
ScriptCustomElementDefinitionBuilder::ScriptCustomElementDefinitionBuilder(
ScriptState* scriptState,
- CustomElementsRegistry* registry,
+ CustomElementRegistry* registry,
const ScriptValue& constructor,
ExceptionState& exceptionState)
: m_prev(s_stack)
@@ -41,7 +41,7 @@ bool ScriptCustomElementDefinitionBuilder::checkConstructorIntrinsics()
{
DCHECK(m_scriptState->world().isMainWorld());
// The signature of CustomElementsRegistry.define says this is a
// Function
// https://html.spec.whatwg.org/multipage/scripting.html#customelementsregistry
CHECK(m_constructorValue->IsFunction());
@@ -41,7 +41,7 @@ bool ScriptCustomElementDefinitionBuilder::checkConstructorIntrinsics()
{
DCHECK(m_scriptState->world().isMainWorld());
- // The signature of CustomElementsRegistry.define says this is a
+ // The signature of CustomElementRegistry.define says this is a
// Function
// https://html.spec.whatwg.org/multipage/scripting.html#customelementsregistry

Powered by Google App Engine
This is Rietveld 408576698